@@ -147,54 +147,3 @@ class CleanProject(AtomicIterable):
             for path, name in NAMES.existing_template_files(dir, mode):
                 if name not in template_dict[NAMES.convert_mode(mode)]:
                     yield remove_path(path)
-
-
-class UpgradeProject(AtomicIterable):
-    def __call__(self, proj_path: ProjectPath, *_) -> Iterable[RuntimeClosure]:
-        import yaml
-        import pytomlpp
-
-        def _callable():
-            yaml_path = proj_path.data_dir / "tpr_info.yaml"
-            old_toml_path = proj_path.data_dir / "tpr_info.toml"
-            if yaml_path.exists():
-                proj_path.template.write_text(
-                    pytomlpp.dumps(yaml.safe_load(yaml_path.read_text()))
-                )
-                yaml_path.unlink()
-            if old_toml_path.exists():
-                old_toml_path.rename(proj_path.template)
-
-            # rename all the files
-            for init, trg, end in [
-                ("macro", "macros", ".sty"),
-                ("citation", "citations", ".bib"),
-                ("format", "style", ".sty"),
-            ]:
-                (proj_path.data_dir / trg).mkdir(exist_ok=True)
-                for path in proj_path.data_dir.glob(f"{init}-*{end}"):
-                    path.rename(
-                        proj_path.data_dir
-                        / trg
-                        / ("local-" + "".join(path.name.split("-")[1:]))
-                    )
-
-            # rename style directory
-            if (proj_path.data_dir / "style").exists():
-                (proj_path.data_dir / "style").rename(proj_path.data_dir / "styles")
-
-            # rename format / style key to list of styles
-            for old_name in ("format", "style"):
-                try:
-                    tpl_dict = pytomlpp.load(proj_path.template)
-                    tpl_dict["styles"] = [tpl_dict.pop(old_name)]
-                    proj_path.template.write_text(pytomlpp.dumps(tpl_dict))
-                except KeyError:
-                    pass
-            return RuntimeOutput(True)
-
-        yield RuntimeClosure(
-            FORMAT_MESSAGE.info("Upgrading repository files"),
-            True,
-            _callable,
-        )
